/**
 * @file avmaicctl.h
 *
 * DaicCtl - Common definitions for the daic maintenance tool.
 *
 * Copyright: 2003 Thomas Wintergerst. All rights reserved.
 *
 * $FreeBSD$
 * $Id: daicctl.h,v 1.4.2.2 2004/12/23 10:41:54 thomas Exp $
 * Project  CAPI for BSD
 * Target   daicctl - Maintenance tool for Diehl legacy active ISDN controllers
 * @date    09.03.2000
 * @author  "Thomas Wintergerst" <twinterg@gmx.de>
 * <p>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * </p>
 *
 * Daicctl is heavily derived from diehlctl by Martin Husemann.
 */


#ifndef __DAICCTL_H
#define __DAICCTL_H





/* === public declarations =============================================== */





/// The name of the CAPI driver for Diehl legacy active ISDN controllers.
#define DAIC_DRIVER_NAME        "daic"

/// The default directory for the download files.
#define DAIC_DEF_DOWNLOAD_DIR   "/usr/share/capi/daic"



/**
 * Structure for sending the configuration data to a board.
 *
 * @attention This structure must be absolutely equal to the one declared in
 *            daic_global.h in the daic driver source.
 */
typedef struct
{
   unsigned char ucTei;         ///< The TEI value to use.
   unsigned char ucNt2;         ///< Flag for point-to-point or multipoint op.
   unsigned char ucSkip1;
   unsigned char ucWatchDog;
   unsigned char ucPermanent;   ///< Flag for a permanent or dial connection.
   unsigned char ucXInterface;
   unsigned char ucStableL2;    ///< D-channel layer 2 connection setting.
   unsigned char ucNoOrderCheck;
   unsigned char ucHandsetType;
   unsigned char ucSkip2;
   unsigned char ucLowChannel;  ///< For S2m: Setting for the channel selection
                                ///< for outgoing calls.
   unsigned char ucProtVersion;
   unsigned char ucCrc4;        ///< For S2m: Setting for CRC4 support.
   unsigned char ucLoopback;
   unsigned char aucOad1 [32];  ///< U.S. protocols: First originator address.
   unsigned char aucOsa1 [32];  ///< U.S. protocols: First originator subaddr.
   unsigned char aucSpid1 [32]; ///< U.S. protocols: First service prot. id.
   unsigned char aucOad2 [32];  ///< U.S. protocols: Second originator address.
   unsigned char aucOsa2 [32];  ///< U.S. protocols: Second originator subaddr.
   unsigned char aucSpid2 [32]; ///< U.S. protocols: Second service prot. id.
   unsigned char ucMemBootOpt;  ///< Flag for the board to perform a memory test.
} DaicBoardConfigData_t;



/// Macro to easily determine the size of fixed arrays.
#define ARRAY_COUNT( a )        (sizeof (a) / sizeof (a [0]))





/* === prototypes of interface functions ================================= */





/* download firmware and configuration data to a controller */
extern void download
   (unsigned  uController,
    int       argc,
    char     *argv []);





#endif /* __DAICCTL_H */
